@@ -108,7 +108,7 @@ void Backend::setCipherType(BackendCipherType ct)
 static int password2PBKDF2_SHA512(const QByteArray &password, QByteArray &hash, const QByteArray &salt)
 {
     if (!gcry_check_version("1.5.0")) {
-        printf("libcrypt version is too old \n");
+        qCWarning(KWALLETBACKEND_LOG) << "libcrypt version is too old";
         return GPG_ERR_USER_2;
     }
 
@@ -117,7 +117,7 @@ static int password2PBKDF2_SHA512(const QByteArray &password, QByteArray &hash,
     if (!gcry_secmem_init) {
         error = gcry_control(GCRYCTL_INIT_SECMEM, 32768, 0);
         if (error != 0) {
-            qWarning() << "Can't get secure memory:" << error;
+            qCWarning(KWALLETBACKEND_LOG) << "Can't get secure memory:" << error;
             return error;
         }
         gcry_secmem_init = true;
@@ -573,7 +573,8 @@ int Backend::renameEntry(const QString &oldName, const QString &newName)
 
         HashMap::iterator i = _hashes.find(MD5Digest(folderMd5.result()));
         if (i != _hashes.end()) {
-            QCryptographicHash oldMd5(QCryptographicHash::Md5), newMd5(QCryptographicHash::Md5);
+            QCryptographicHash oldMd5(QCryptographicHash::Md5);
+            QCryptographicHash newMd5(QCryptographicHash::Md5);
             oldMd5.addData(oldName.toUtf8());
             newMd5.addData(newName.toUtf8());
             i.value().removeAll(MD5Digest(oldMd5.result()));
